Enum Data
pub enum Data {
Struct(MoveStruct),
Package(MovePackage),
}Expand description
Object data, either a package or struct
BCS
The BCS serialized form for this type is defined by the following ABNF:
object-data = object-data-struct / object-data-package
object-data-struct = %d00 object-move-struct
object-data-package = %d01 object-move-packageVariants
Struct(MoveStruct)
An object whose governing logic lives in a published Move module
Package(MovePackage)
Map from each module name to raw serialized Move module bytes
Implementations
impl ObjectData
impl ObjectData
pub fn as_struct(&self) -> &MoveStruct
pub fn as_struct(&self) -> &MoveStruct
Converts this into a struct if it is a struct variant, or panics otherwise.
pub fn as_struct_mut(&mut self) -> &mut MoveStruct
pub fn as_struct_mut(&mut self) -> &mut MoveStruct
Converts this into a mut struct if it is a struct variant, or panics otherwise.
pub fn as_struct_opt(&self) -> Option<&MoveStruct>
pub fn as_struct_opt(&self) -> Option<&MoveStruct>
Converts this into a struct if it is a struct variant, or returns None otherwise.
pub fn as_struct_mut_opt(&mut self) -> Option<&mut MoveStruct>
pub fn as_struct_mut_opt(&mut self) -> Option<&mut MoveStruct>
Converts this into a mut struct if it is a struct variant, or returns None otherwise.
pub fn into_struct_opt(self) -> Option<MoveStruct>
pub fn into_struct_opt(self) -> Option<MoveStruct>
Converts this into a struct if it is a struct variant, or returns None otherwise.
pub fn into_struct(self) -> MoveStruct
pub fn into_struct(self) -> MoveStruct
Converts this into a struct if it is a struct variant, or panics otherwise.
pub fn is_package(&self) -> bool
pub fn is_package(&self) -> bool
Checks if this is a package variant.
pub fn as_package(&self) -> &MovePackage
pub fn as_package(&self) -> &MovePackage
Converts this into a package if it is a package variant, or panics otherwise.
pub fn as_package_mut(&mut self) -> &mut MovePackage
pub fn as_package_mut(&mut self) -> &mut MovePackage
Converts this into a mut package if it is a package variant, or panics otherwise.
pub fn as_package_opt(&self) -> Option<&MovePackage>
pub fn as_package_opt(&self) -> Option<&MovePackage>
Converts this into a package if it is a package variant, or returns None otherwise.
pub fn as_package_mut_opt(&mut self) -> Option<&mut MovePackage>
pub fn as_package_mut_opt(&mut self) -> Option<&mut MovePackage>
Converts this into a mut package if it is a package variant, or returns None otherwise.
pub fn into_package_opt(self) -> Option<MovePackage>
pub fn into_package_opt(self) -> Option<MovePackage>
Converts this into a package if it is a package variant, or returns None otherwise.
pub fn into_package(self) -> MovePackage
pub fn into_package(self) -> MovePackage
Converts this into a package if it is a package variant, or panics otherwise.
pub fn object_type(&self) -> Option<&MoveObjectType>
pub fn struct_tag(&self) -> Option<StructTag>
pub fn id(&self) -> ObjectId