Struct ObjectInner
pub struct ObjectInner {
pub data: ObjectData,
pub owner: Owner,
pub previous_transaction: Digest,
pub storage_rebate: u64,
}Expand description
An object on the IOTA blockchain
BCS
The BCS serialized form for this type is defined by the following ABNF:
object = object-data owner digest u64Fields
data: ObjectDataThe meat of the object
owner: OwnerThe owner that unlocks this object
previous_transaction: DigestThe digest of the transaction that created or last mutated this object
storage_rebate: u64The amount of IOTA we would rebate if this object gets deleted. This number is re-calculated each time the object is mutated based on the present storage gas price.
Implementations
impl Object
impl Object
pub fn new(
data: ObjectData,
owner: Owner,
previous_transaction: Digest,
storage_rebate: u64,
) -> Object
pub fn new( data: ObjectData, owner: Owner, previous_transaction: Digest, storage_rebate: u64, ) -> Object
Build an object
pub fn id(&self) -> ObjectId
pub fn id(&self) -> ObjectId
Return this object’s id
pub fn object_ref(&self) -> ObjectReference
pub fn object_ref(&self) -> ObjectReference
Return this object’s reference
pub fn object_type(&self) -> ObjectType
pub fn object_type(&self) -> ObjectType
Return this object’s type
pub fn as_struct_opt(&self) -> Option<&MoveStruct>
pub fn as_struct_opt(&self) -> Option<&MoveStruct>
Try to interpret this object as a move struct
pub fn as_struct(&self) -> &MoveStruct
pub fn as_struct(&self) -> &MoveStruct
Interpret this object as a move struct
pub fn as_package_opt(&self) -> Option<&MovePackage>
pub fn as_package_opt(&self) -> Option<&MovePackage>
Try to interpret this object as a move package
pub fn as_package(&self) -> &MovePackage
pub fn as_package(&self) -> &MovePackage
Interpret this object as a move package
pub fn owner(&self) -> &Owner
pub fn owner(&self) -> &Owner
Return this object’s owner
pub fn data(&self) -> &ObjectData
pub fn data(&self) -> &ObjectData
Return this object’s data
pub fn previous_transaction(&self) -> Digest
pub fn previous_transaction(&self) -> Digest
Return the digest of the transaction that last modified this object
pub fn storage_rebate(&self) -> u64
pub fn storage_rebate(&self) -> u64
Return the storage rebate locked in this object
Storage rebates are credited to the gas coin used in a transaction that deletes this object.
pub fn to_rust<'de, T>(&'de self) -> Result<T, Box<dyn Error + Send + Sync>>where
T: Deserialize<'de>,
pub fn is_immutable(&self) -> bool
pub fn is_immutable(&self) -> bool
Returns true if the object is immutable.
pub fn is_address_owned(&self) -> bool
pub fn is_address_owned(&self) -> bool
Returns true if the object is owned by an address.
pub fn is_child_object(&self) -> bool
pub fn is_child_object(&self) -> bool
Returns true if the object is owned by another object.
Returns true if the object is shared.
pub fn is_package(&self) -> bool
pub fn is_package(&self) -> bool
Returns true if this object is a Move package rather than a Move value.
pub fn is_system_package(&self) -> bool
pub fn is_system_package(&self) -> bool
Returns true if the object is a system package.
pub fn struct_tag(&self) -> Option<StructTag>
pub fn struct_tag(&self) -> Option<StructTag>
Returns the struct tag of this object if it is a Move struct.
pub fn is_gas_coin(&self) -> bool
pub fn is_gas_coin(&self) -> bool
Returns true if this object is a gas coin.
pub fn coin_type_opt(&self) -> Option<&TypeTag>
pub fn coin_type_opt(&self) -> Option<&TypeTag>
Returns the coin’s type parameter if this object is a coin.
pub fn single_owner(&self) -> Option<Address>
pub fn single_owner(&self) -> Option<Address>
Returns the address of the single owner of this object (address- or
object-owned), or None if it is shared or immutable.
pub fn set_owner(&mut self, new_owner: Address)
pub fn set_owner(&mut self, new_owner: Address)
Sets the owner of this object to new_owner.