pub struct Object(/* private fields */);Implementations
Sourceimpl Object
impl Object
pub fn into_inner(self) -> ObjectInner
pub fn as_inner(&self) -> &ObjectInner
pub fn new_from_genesis( data: ObjectData, owner: Owner, previous_transaction: TransactionDigest, ) -> Self
Sourcepub fn new_move(
o: MoveObject,
owner: Owner,
previous_transaction: TransactionDigest,
) -> Self
pub fn new_move( o: MoveObject, owner: Owner, previous_transaction: TransactionDigest, ) -> Self
Create a new Move object
pub fn new_package_from_data( data: ObjectData, previous_transaction: TransactionDigest, ) -> Self
pub fn new_from_package( package: MovePackage, previous_transaction: TransactionDigest, ) -> Self
pub fn new_package<'p>( modules: &[CompiledModule], previous_transaction: TransactionDigest, protocol_config: &ProtocolConfig, dependencies: impl IntoIterator<Item = &'p MovePackage>, ) -> Result<Self, ExecutionError>
pub fn new_upgraded_package<'p>( previous_package: &MovePackage, new_package_id: ObjectId, modules: &[CompiledModule], previous_transaction: TransactionDigest, protocol_config: &ProtocolConfig, dependencies: impl IntoIterator<Item = &'p MovePackage>, ) -> Result<Self, ExecutionError>
pub fn new_package_for_testing( modules: &[CompiledModule], previous_transaction: TransactionDigest, dependencies: impl IntoIterator<Item = MovePackage>, ) -> Result<Self, ExecutionError>
Sourcepub fn new_system_package(
modules: &[CompiledModule],
version: SequenceNumber,
dependencies: Vec<ObjectId>,
previous_transaction: TransactionDigest,
) -> Self
pub fn new_system_package( modules: &[CompiledModule], version: SequenceNumber, dependencies: Vec<ObjectId>, previous_transaction: TransactionDigest, ) -> Self
Create a system package which is not subject to size limits. Panics if the object ID is not a known system package.
Sourceimpl Object
impl Object
pub fn type_(&self) -> Option<&MoveObjectType>
pub fn is_coin(&self) -> bool
pub fn as_coin_maybe(&self) -> Option<Coin>
pub fn as_timelock_balance_maybe(&self) -> Option<TimeLock<Balance>>
Sourcepub fn get_coin_value_unchecked(&self) -> u64
pub fn get_coin_value_unchecked(&self) -> u64
Return the value: u64 field of a Coin<T> type.
Useful for reading the coin without deserializing the object into a Move
value It is the caller’s responsibility to check that self is a
coin–this function may panic or do something unexpected otherwise.
Sourcepub fn object_size_for_gas_metering(&self) -> usize
pub fn object_size_for_gas_metering(&self) -> usize
Approximate size of the object in bytes. This is used for gas metering. This will be slightly different from the serialized size, but we also don’t want to serialize the object just to get the size. This approximation should be good enough for gas metering.
Sourcepub fn get_layout(
&self,
resolver: &impl GetModule,
) -> Result<Option<MoveStructLayout>, IotaError>
pub fn get_layout( &self, resolver: &impl GetModule, ) -> Result<Option<MoveStructLayout>, IotaError>
Get a MoveStructLayout for self.
The resolver value must contain the module that declares
self.object_type and the (transitive) dependencies of
self.object_type in order for this to succeed. Failure will result
in an ObjectSerializationError
Sourcepub fn get_move_template_type(&self) -> IotaResult<TypeTag>
pub fn get_move_template_type(&self) -> IotaResult<TypeTag>
Treat the object type as a Move struct with one type parameter,
like this: S<T>.
Returns the inner parameter type T.
Sourceimpl Object
impl Object
Sourcepub fn get_total_iota(
&self,
layout_resolver: &mut dyn LayoutResolver,
) -> Result<u64, IotaError>
pub fn get_total_iota( &self, layout_resolver: &mut dyn LayoutResolver, ) -> Result<u64, IotaError>
Get the total amount of IOTA embedded in self, including both Move
objects and the storage rebate
pub fn immutable_with_id_for_testing(id: ObjectId) -> Self
pub fn immutable_for_testing() -> Self
Make a new random test shared object.
pub fn with_id_owner_gas_for_testing( id: ObjectId, owner: Address, gas: u64, ) -> Self
pub fn treasury_cap_for_testing( struct_tag: StructTag, treasury_cap: TreasuryCap, ) -> Self
pub fn coin_metadata_for_testing( struct_tag: StructTag, metadata: CoinMetadata, ) -> Self
pub fn with_object_owner_for_testing(id: ObjectId, owner: ObjectId) -> Self
pub fn with_id_owner_for_testing(id: ObjectId, owner: Address) -> Self
pub fn with_id_owner_version_for_testing( id: ObjectId, version: SequenceNumber, owner: Owner, ) -> Self
pub fn with_owner_for_testing(owner: Address) -> Self
Sourcepub fn new_gas_with_balance_and_owner_for_testing(
value: u64,
owner: Address,
) -> Self
pub fn new_gas_with_balance_and_owner_for_testing( value: u64, owner: Address, ) -> Self
Generate a new gas coin worth value with a random object ID and owner
For testing purposes only
Sourcepub fn new_gas_for_testing() -> Self
pub fn new_gas_for_testing() -> Self
Generate a new gas coin object with default balance and random owner.
Methods from Deref<Target = ObjectInner>
pub fn digest(&self) -> Digest
pub fn digest(&self) -> Digest
Calculate the digest of this Object
This is done by hashing the BCS bytes of this Object prefixed
with a salt.
pub fn id(&self) -> ObjectId
pub fn id(&self) -> ObjectId
Return this object’s id
pub fn object_ref(&self) -> ObjectReference
pub fn object_ref(&self) -> ObjectReference
Return this object’s reference
pub fn object_type(&self) -> ObjectType
pub fn object_type(&self) -> ObjectType
Return this object’s type
pub fn as_struct_opt(&self) -> Option<&MoveStruct>
pub fn as_struct_opt(&self) -> Option<&MoveStruct>
Try to interpret this object as a move struct
pub fn as_struct(&self) -> &MoveStruct
pub fn as_struct(&self) -> &MoveStruct
Interpret this object as a move struct
pub fn as_package_opt(&self) -> Option<&MovePackage>
pub fn as_package_opt(&self) -> Option<&MovePackage>
Try to interpret this object as a move package
pub fn as_package(&self) -> &MovePackage
pub fn as_package(&self) -> &MovePackage
Interpret this object as a move package
pub fn owner(&self) -> &Owner
pub fn owner(&self) -> &Owner
Return this object’s owner
pub fn data(&self) -> &ObjectData
pub fn data(&self) -> &ObjectData
Return this object’s data
pub fn previous_transaction(&self) -> Digest
pub fn previous_transaction(&self) -> Digest
Return the digest of the transaction that last modified this object
pub fn storage_rebate(&self) -> u64
pub fn storage_rebate(&self) -> u64
Return the storage rebate locked in this object
Storage rebates are credited to the gas coin used in a transaction that deletes this object.
pub fn to_rust<'de, T>(&'de self) -> Result<T, Box<dyn Error + Send + Sync>>where
T: Deserialize<'de>,
pub fn is_immutable(&self) -> bool
pub fn is_immutable(&self) -> bool
Returns true if the object is immutable.
pub fn is_address_owned(&self) -> bool
pub fn is_address_owned(&self) -> bool
Returns true if the object is owned by an address.
pub fn is_child_object(&self) -> bool
pub fn is_child_object(&self) -> bool
Returns true if the object is owned by another object.
Returns true if the object is shared.
pub fn is_package(&self) -> bool
pub fn is_package(&self) -> bool
Returns true if this object is a Move package rather than a Move value.
pub fn is_system_package(&self) -> bool
pub fn is_system_package(&self) -> bool
Returns true if the object is a system package.
pub fn struct_tag(&self) -> Option<StructTag>
pub fn struct_tag(&self) -> Option<StructTag>
Returns the struct tag of this object if it is a Move struct.
pub fn is_gas_coin(&self) -> bool
pub fn is_gas_coin(&self) -> bool
Returns true if this object is a gas coin.
pub fn coin_type_opt(&self) -> Option<&TypeTag>
pub fn coin_type_opt(&self) -> Option<&TypeTag>
Returns the coin’s type parameter if this object is a coin.
pub fn single_owner(&self) -> Option<Address>
pub fn single_owner(&self) -> Option<Address>
Returns the address of the single owner of this object (address- or
object-owned), or None if it is shared or immutable.
pub fn set_owner(&mut self, new_owner: Address)
pub fn set_owner(&mut self, new_owner: Address)
Sets the owner of this object to new_owner.